@@ -9,9 +9,10 @@
 #' @param pattern Character string to be matched in \code{data}. May also be a
 #'          character vector of length > 1 (see 'Examples'). \code{pattern} is
 #'          searched for in column names and variable label attributes of
-#'          \code{data} (see \code{\link[sjlabelled]{get_label}}). \code{pattern} might also
-#'          be a regular-expression object, as returned by \code{\link[stringr]{regex}},
-#'          or any of \pkg{stringr}'s supported \code{\link[stringr]{modifiers}}.
+#'          \code{data} (see \code{\link[sjlabelled]{get_label}}). \code{pattern}
+#'          might also be a regular-expression object, as returned by \code{\link[stringr]{regex}}.
+#'          Alternatively, use \code{regex = TRUE} to treat \code{pattern} as a regular
+#'          expression rather than a fixed string.
 #' @param ignore.case Logical, whether matching should be case sensitive or not.
 #' @param search Character string, indicating where \code{pattern} is sought.
 #'          Use one of following options:
@@ -44,10 +45,9 @@
 #'          }
 #' @param fuzzy Logical, if \code{TRUE}, "fuzzy matching" (partial and
 #'          close distance matching) will be used to find \code{pattern}
-#'          in \code{data} if no exact match was found. \code{\link{str_pos}}
-#'          is used for fuzzy matching.
-#' @param as.df Deprecated, use \code{out = "df"} instead.
-#' @param as.varlab Deprecated, use \code{out = "table" instead.}
+#'          in \code{data} if no exact match was found.
+#' @param regex Logical, if \code{TRUE}, \code{pattern} is treated as a regular
+#'          expression rather than a fixed string.
 #'
 #' @return By default (i.e. \code{out = "table"}, returns a data frame with three
 #'         columns: column number, variable name and variable label. If
@@ -58,10 +58,8 @@
 #' @details This function searches for \code{pattern} in \code{data}'s column names
 #'            and - for labelled data - in all variable and value labels of \code{data}'s
 #'            variables (see \code{\link[sjlabelled]{get_label}} for details on variable labels and
-#'            labelled data). Search is performed using the
-#'            \code{\link[stringr]{str_detect}} functions; hence, regular
-#'            expressions are supported as well, by simply using
-#'            \code{pattern = stringr::regex(...)}.
+#'            labelled data). Regular expressions are supported as well, by simply using
+#'            \code{pattern = stringr::regex(...)} or \code{regex = TRUE}.
 #'
 #' @examples
 #' data(efc)
@@ -90,7 +88,6 @@
 #' library(sjPlot)
 #' view_df(res)}
 #'
-#' @importFrom stringr regex coll str_detect
 #' @importFrom sjlabelled get_labels
 #' @importFrom purrr map_lgl
 #' @export
@@ -100,8 +97,7 @@ find_var <- function(data,
                      search = c("name_label", "name_value", "label_value", "name", "label", "value", "all"),
                      out = c("table", "df", "index"),
                      fuzzy = FALSE,
-                     as.df,
-                     as.varlab) {
+                     regex = FALSE) {
   # check valid args
   if (!is.data.frame(data)) {
     stop("`data` must be a data frame.", call. = F)
@@ -111,77 +107,48 @@ find_var <- function(data,
   search <- match.arg(search)
   out <- match.arg(out)
 
-  # check deprecated
-  if (!missing(as.df)) {
-    message("`as.df` is deprecated. Please use `out = \"df\" instead.")
-    out <- "df"
-  }
-
-  if (!missing(as.varlab)) {
-    message("`as.varlab` is deprecated. Please use `out = \"table\" instead.")
-    out <- "table"
-  }
-
+  if (regex) class(pattern) <- c("regex", class(pattern))
 
   pos1 <- pos2 <- pos3 <- c()
+  fixed <- !inherits(pattern, "regex")
+  if (isTRUE(fixed)) ignore.case <- FALSE
 
   # search for pattern in variable names
   if (search %in% c("name", "name_label", "name_value", "all")) {
-    # check variable names
-    if (inherits(pattern, "regex"))
-      pos1 <- which(stringr::str_detect(colnames(data), pattern))
-    else
-      pos1 <- which(stringr::str_detect(colnames(data), stringr::coll(pattern, ignore_case = ignore.case)))
+    pos1 <- which(grepl(pattern = pattern, x = colnames(data), ignore.case = ignore.case, fixed = fixed))
 
     # if nothing found, find in near distance
     if (sjmisc::is_empty(pos1) && fuzzy && !inherits(pattern, "regex")) {
-      pos1 <- str_pos(search.string = colnames(data), find.term = pattern, part.dist.match = 1)
+      pos1 <- fuzzy_grep(x = colnames(data), pattern = pattern)
     }
   }
 
-
   # search for pattern in variable labels
   if (search %in% c("label", "name_label", "label_value", "all")) {
-    # get labels and variable names
     labels <- sjlabelled::get_label(data)
-
-    # check labels
-    if (inherits(pattern, "regex"))
-      pos2 <- which(stringr::str_detect(labels, pattern))
-    else
-      pos2 <- which(stringr::str_detect(labels, stringr::coll(pattern, ignore_case = ignore.case)))
+    pos2 <- which(grepl(pattern, x = labels, ignore.case = ignore.case, fixed = fixed))
 
     # if nothing found, find in near distance
     if (sjmisc::is_empty(pos2) && fuzzy && !inherits(pattern, "regex")) {
-      pos2 <- str_pos(search.string = labels, find.term = pattern, part.dist.match = 1)
+      pos2 <- fuzzy_grep(x = labels, pattern = pattern)
     }
   }
 
   # search for pattern in value labels
   if (search %in% c("value", "name_value", "label_value", "all")) {
     labels <- sjlabelled::get_labels(data, attr.only = F)
-
-    # check value labels with regex
-    if (inherits(pattern, "regex")) {
-      pos3 <- which(purrr::map_lgl(labels, ~ any(stringr::str_detect(.x, pattern))))
-    } else {
-      pos3 <-
-        which(purrr::map_lgl(labels, ~ any(stringr::str_detect(
-          .x, stringr::coll(pattern, ignore_case = ignore.case)
-        ))))
-    }
+    pos3 <- which(purrr::map_lgl(labels, ~ any(grepl(pattern, x = .x, ignore.case = ignore.case, fixed = fixed))))
 
     # if nothing found, find in near distance
     if (sjmisc::is_empty(pos3) && fuzzy && !inherits(pattern, "regex")) {
       pos3 <- which(purrr::map_lgl(
         labels,
         function(.x) {
-          p <- str_pos(
-            search.string = .x,
-            find.term = pattern,
-            part.dist.match = 1
+          p <- fuzzy_grep(
+            x = .x,
+            pattern = pattern
           )
-          p[1] != -1
+          !sjmisc::is_empty(p[1])
         }))
     }
   }
